<?php

/*-----------------------------------------------------------------------------------
- Default
----------------------------------------------------------------------------------- */

add_action( 'after_setup_theme', 'gratia_theme_setup' );

function gratia_theme_setup() {
	global $content_width;

	/* Set the $content_width for things such as video embeds. */
	if ( !isset( $content_width ) )
		$content_width = 699;

	/* Add theme support for automatic feed links. */
	add_theme_support( 'post-formats', array( 'video','audio', 'gallery','quote', 'link', 'aside' ) );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'custom-background' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'responsive-embeds' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
	
	
	/* Add theme support for post thumbnails (featured images). */	
	add_theme_support('post-thumbnails');
	add_image_size('gratia_header', 1920, 900, true ); 	//(cropped)
	add_image_size('gratia_blog', 391, 9999, false ); 			//(un-cropped)
	add_image_size('gratia_small', 254, 180, true ); 			//(cropped)
	

	/* Add custom menus */
	register_nav_menus(array(
		'main-menu' => esc_html__( 'Main Menu','gratia' ),
		'bottom-menu' => esc_html__( 'Footer Menu','gratia' ),
	));

	/* Add your sidebars function to the 'widgets_init' action hook. */
	add_action( 'widgets_init', 'gratia_register_sidebars' );
	
	/* Make theme available for translation */
	load_theme_textdomain('gratia', get_template_directory() . '/lang' );

}

function gratia_register_sidebars() {
	
	register_sidebar(
		array(
			'name' => esc_html__( 'Sidebar','gratia' ),
			'id' => 'tmnf-sidebar',
			'description' => esc_html__( 'Sidebar widget section (displayed on posts / blog)','gratia' ),
			'before_widget' => '<div class="sidebar_item">',
			'after_widget' => '</div>',
			'before_title' => '<h5 class="widget"><span>',
			'after_title' => '</span></h5>'
		)
	);
	
	register_sidebar(
		array(
			'name' => esc_html__( 'Sidebar (Fly Off)','gratia' ),
			'id' => 'tmnf-sidebar-flyoff',
			'description' => esc_html__( 'Sidebar widget section (hidden, accessible via menu button)','gratia' ),
			'before_widget' => '<div class="sidebar_item">',
			'after_widget' => '</div>',
			'before_title' => '<h5 class="widget">',
			'after_title' => '</h5>'
		)
	);

	//footer widgets
	register_sidebar(
		array(
			'name' => esc_html__( 'Footer 1','gratia' ),
			'id' => 'tmnf-footer-1',
			'description' => esc_html__( 'Widget section in footer - left','gratia' ),
			'before_widget' => '<div class="sidebar_item">',
			'after_widget' => '</div>',
			'before_title' => '<h5 class="widget">',
			'after_title' => '</h5>'
		)
	);
	register_sidebar(
		array(
			'name' => esc_html__( 'Footer 2','gratia' ),
			'id' => 'tmnf-footer-2',
			'description' => esc_html__( 'Widget section in footer - center/left','gratia' ),
			'before_widget' => '<div class="sidebar_item">',
			'after_widget' => '</div>',
			'before_title' => '<h5 class="widget">',
			'after_title' => '</h5>'
		)
	);
	register_sidebar(
		array(
			'name' => esc_html__( 'Footer 3','gratia' ),
			'id' => 'tmnf-footer-3',
			'description' => esc_html__( 'Widget section in footer - center/right','gratia' ),
			'before_widget' => '<div class="sidebar_item">',
			'after_widget' => '</div>',
			'before_title' => '<h5 class="widget">',
			'after_title' => '</h5>'
		)
	);
	register_sidebar(
		array(
			'name' => esc_html__( 'Footer 4','gratia' ),
			'id' => 'tmnf-footer-4',
			'description' => esc_html__( 'Widget section in footer - right','gratia' ),
			'before_widget' => '<div class="sidebar_item">',
			'after_widget' => '</div>',
			'before_title' => '<h5 class="widget">',
			'after_title' => '</h5>'
		)
	);
	
	//woo widgets
	if ( class_exists( 'WooCommerce' ) ) {
		register_sidebar(
			array(
				'name' => esc_html__( 'Shop Sidebar','gratia' ),
				'id' => 'tmnf-shop-sidebar',
				'description' => esc_html__( 'Sidebar widget section (displayed on shop pages)','gratia' ),
				'before_widget' => '<div class="sidebar_item">',
				'after_widget' => '</div>',
				'before_title' => '<h5 class="widget"><span>',
				'after_title' => '</span></h5>'
			)
		);
	}

}

// Add a pingback url auto-discovery header for single posts, pages, or attachments.
function gratia_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'gratia_pingback_header' );

/*-----------------------------------------------------------------------------------
- Framework - Please refrain from editing this section 
----------------------------------------------------------------------------------- */


// Set path to Framework and theme specific functions
$functions_path = get_template_directory() . '/functions/';

// Theme specific functionality
require_once ($functions_path . 'admin-functions.php');					// Custom functions and plugins

// Add Redux options panel
if ( !isset( $themnific_redux ) && file_exists( get_template_directory()  . '/redux-framework/redux-themnific.php' ) ) {
    require_once( get_template_directory()  . '/redux-framework/redux-themnific.php' );
}

	
/*-----------------------------------------------------------------------------------
- Enqueues scripts and styles for front end
----------------------------------------------------------------------------------- */ 

function gratia_enqueue_style() {
	
	// Main stylesheet
	wp_enqueue_style( 'gratia-style', get_stylesheet_uri());
	
	// sermon-addons
	wp_enqueue_style('sermon-addons', get_template_directory_uri() .	'/styles/sermon-addons.css');
	
	// Font Awesome css	
	wp_enqueue_style('fontawesome', get_template_directory_uri() .	'/styles/fontawesome.css');
	
}
add_action( 'wp_enqueue_scripts', 'gratia_enqueue_style' );




// themnific custom css + chnage the order of how the sytlesheets are loaded, and overrides WooCommerce styles.
function gratia_custom_order() {
	
	// place wooCommerce styles before our main stlesheet
	if ( class_exists( 'WooCommerce' ) ) {
		wp_dequeue_style( 'woocommerce_frontend_styles' );
		wp_enqueue_style('woocommerce-frontend-styles', plugins_url() .'/woocommerce/assets/css/woocommerce.css');
	
		wp_enqueue_style('gratia-woo-custom', get_template_directory_uri().	'/styles/woo-custom.css');
		wp_enqueue_style('gratia-mobile', get_template_directory_uri().'/style-mobile.css');
	} else {
		wp_enqueue_style('gratia-mobile', get_template_directory_uri().'/style-mobile.css');
	}
}
add_action('wp_enqueue_scripts', 'gratia_custom_order');


function gratia_enqueue_script() {	

		// Load Common scripts	
		wp_enqueue_script('gratia-ownscript', get_template_directory_uri() .'/js/ownScript.js',array( 'jquery' ),'', true);

		// Load masonry
		if (is_archive()||is_home()||is_search()||is_page_template('template-sermons.php')||is_page_template('template-donation.php')) {
			wp_enqueue_script('masonry');		
			wp_enqueue_script('gratia-masonry-start', get_template_directory_uri() .'/js/masonry.start.js',array( 'jquery' ),'', true);
		}
		
		// Singular comment script		
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
			wp_enqueue_script( 'comment-reply' );

}
	
add_action('wp_enqueue_scripts', 'gratia_enqueue_script');


/*-----------------------------------------------------------------------------------
- TGM_Plugin_Activation class.
----------------------------------------------------------------------------------- */
require_once get_template_directory()  . '/class-tgm-plugin-activation.php';

add_action( 'tgmpa_register', 'gratia_register_required_plugins' );
function gratia_register_required_plugins() {

    $plugins = array(
	

        // redux-framework
        array(
            'name'				=> esc_html__( 'Redux Framework','gratia' ),
            'slug'      		=> 'redux-framework',
            'required'  		=> true,
        ),
        // elementor
        array(
            'name'				=> esc_html__( 'Elementor','gratia' ),
            'slug'      		=> 'elementor',
            'required'  		=> true,
        ),               
		// sermon-addons
        array(
            'name'				=> esc_html__( 'Sermon Addons','gratia' ),
            'slug'      		=> 'sermon-addons',
			'source'            => get_template_directory() . '/plugin/sermon-addons.zip', // The plugin source.
            'required'  		=> true,
        ),  
		// give
        array(
            'name'				=> esc_html__( 'Give – Donation Plugin','gratia' ),
            'slug'      		=> 'give',
            'required'  		=> false,
        ),          
		// events-manager
        array(
            'name'				=> esc_html__( 'Events Manager','gratia' ),
            'slug'      		=> 'events-manager',
            'required'  		=> false,
        ),    
        // one-click-demo-import
        array(
            'name'				=> esc_html__( 'One Click Demo Import','gratia' ),
            'slug'      		=> 'one-click-demo-import',
            'required'  		=> false,
        ),  

    );
    $config = array(
        'id'           => 'tgmpa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
        'default_path' => '',                      // Default absolute path to pre-packaged plugins.
        'menu'         => 'tgmpa-install-plugins', // Menu slug.
        'has_notices'  => true,                    // Show admin notices or not.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => false,                   // Automatically activate plugins after installation or not.
        'message'      => '',                      // Message to output right before the plugins table.
        'strings'      => array(
            'page_title'                      => esc_html__( 'Install Required Plugins','gratia' ),
            'menu_title'                      => esc_html__( 'Install Plugins','gratia' ),
            'installing'                      => esc_html__( 'Installing Plugin: %s','gratia' ), // %s = plugin name.
            'oops'                            => esc_html__( 'Something went wrong with the plugin API.','gratia' ),
            'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.','This theme requires the following plugins: %1$s.','gratia' ), // %1$s = plugin name(s).
            'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.','This theme recommends the following plugins: %1$s.','gratia' ), // %1$s = plugin name(s).
            'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.','gratia' ), // %1$s = plugin name(s).
            'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.','gratia' ), // %1$s = plugin name(s).
            'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.','gratia' ), // %1$s = plugin name(s).
            'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.','gratia' ), // %1$s = plugin name(s).
            'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.','gratia' ), // %1$s = plugin name(s).
            'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.','gratia' ), // %1$s = plugin name(s).
            'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins','gratia' ),
            'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins','gratia' ),
            'return'                          => esc_html__( 'Return to Required Plugins Installer','gratia' ),
            'plugin_activated'                => esc_html__( 'Plugin activated successfully.','gratia' ),
            'complete'                        => esc_html__( 'All plugins installed and activated successfully. %s','gratia' ), // %s = dashboard link.
            'nag_type'                        => 'updated' // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
        )
    );

    tgmpa( $plugins, $config );

}

	
/*-----------------------------------------------------------------------------------
- Other theme functions
----------------------------------------------------------------------------------- */

// register custom fonts for Gutenberg

function gratia_gutenberg_styles() {

	// Load the theme styles within Gutenberg.
	wp_enqueue_style( 'gratia-gutenberg', get_theme_file_uri( '/styles/style-editor.css' ), false, '1.1.1', 'all' );

	// Add custom fonts to Gutenberg.
	wp_enqueue_style( 'gratia-fonts', gratia_admin_fonts_url(), array(), null );
}
add_action( 'enqueue_block_editor_assets', 'gratia_gutenberg_styles' );

/**
 * Register custom fonts.
 */
function gratia_admin_fonts_url() {
	$fonts_url = '';
	$firstfont = esc_html_x( 'on', 'Montagu Slab font: on or off', 'gratia' );
	$secondfont = esc_html_x( 'on', 'DM Sans: on or off', 'gratia' );

	if ( 'off' !== $firstfont || 'off' !== $secondfont ) {
		$font_families = array();

		if ( 'off' !== $firstfont ) {
			$font_families[] = 'Montagu Slab:400,500,600,700,800';
		}

		if ( 'off' !== $secondfont ) {
			$font_families[] = 'DM Sans:400,400i,500,600,700';
		}

		$query_args = array(
			'family' => rawurlencode( implode( '|', $font_families ) ),
			'subset' => rawurlencode( 'latin,latin-ext' ),
		);

		$fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
	}

	return esc_url_raw( $fonts_url );
}



// icons - font awesome
function gratia_icon() {
	
	if(has_post_format('audio')) {return '<i title="'. esc_attr__('Audio','gratia').'" class="tmnf_icon ribbon fas fa-volume-up"></i>';
	}elseif(has_post_format('gallery')) {return '<i title="'. esc_attr__('Gallery','gratia').'" class="tmnf_icon ribbon fas fa-camera"></i>';
	}elseif(has_post_format('image')) {return '<i title="'. esc_attr__('Image','gratia').'" class="tmnf_icon ribbon fas fa-camera"></i>';	
	}elseif(has_post_format('link')) {return '<i title="'. esc_attr__('Link','gratia').'" class="tmnf_icon ribbon fas fa-link"></i>';			
	}elseif(has_post_format('quote')) {return '<i title="'. esc_attr__('Quote','gratia').'" class="tmnf_icon ribbon fas fa-quote-right"></i>';		
	}elseif(has_post_format('video')) {return '<i title="'. esc_attr__('Video','gratia').'" class="tmnf_icon ribbon fas fa-play-circle"></i>';
	}	
	
}


// link format
function gratia_permalink() {
	$linkformat = get_post_meta(get_the_ID(), 'themnific_linkss', true);
	if($linkformat) echo esc_url($linkformat); else the_permalink();
}




// new excerpt function
function gratia_excerpt($text, $chars = 1620) {
	$text = $text." ";
	$text = substr($text,0,$chars);
	$text = substr($text,0,strrpos($text,' '));
	$text = $text."";
	return $text;
}

function gratia_trim_excerpt($text) {
     $text = str_replace('[', '', $text);
     $text = str_replace(']', '', $text);
     return $text;
    }
add_filter('get_the_excerpt', 'gratia_trim_excerpt');

// excerpt class
function gratia_class_to_excerpt( $excerpt ){
    return '<div class="tmnf_excerpt">'.$excerpt.'</div>';
}
add_action('the_excerpt','gratia_class_to_excerpt');



// meta sections

function gratia_meta_date() { ?>   
	<p class="meta <?php $themnific_redux = get_option( 'themnific_redux' ); if(isset($themnific_redux['tmnf-post-meta-dis']) ? $themnific_redux['tmnf-post-meta-dis'] : null) echo 'tmnf_hide';?>">
		<span class="post-date"><?php the_time(get_option('date_format')); ?></span>
    </p>
<?php }

function gratia_meta_front() { ?>   
	<p class="meta <?php $themnific_redux = get_option( 'themnific_redux' ); if(isset($themnific_redux['tmnf-post-meta-dis']) ? $themnific_redux['tmnf-post-meta-dis'] : null) echo 'tmnf_hide';?>">
		<span class="post-date"><?php the_time(get_option('date_format')); ?><span class="divider">&bull;</span></span>
        <span class="categs"><?php the_category(', ') ?></span>
    </p>
<?php }

function gratia_meta_full() { ?>    
	<p class="meta meta_full <?php $themnific_redux = get_option( 'themnific_redux' ); if(isset($themnific_redux['tmnf-post-meta-dis']) ? $themnific_redux['tmnf-post-meta-dis'] : null) echo 'tmnf_hide';?>">
        <?php 
		echo '<span class="author"><i class="icon-user"></i> '; the_author_posts_link();echo '<span class="divider">&bull;</span></span>';
		?>
		<span class="post-date"><i class="icon-clock-alt"></i> <?php the_time(get_option('date_format')); ?><span class="divider">&bull;</span></span>
		<span class="categs"><i class="icon-doc"></i> <?php the_category(', ') ?></span>
		<?php if ('tmnf_sermon' == get_post_type()) {
			$sermon_speaker = get_post_meta(get_the_ID(), 'sermon_speaker', true);
		?>

			<span class="sermon_categs"><i class="icon-doc"></i> 
				<?php
				$terms = get_the_terms( get_the_ID() , 'sermon-category' );
				foreach ( $terms as $term ) {
				echo '<a href="'.get_term_link($term->term_id).'"><span>&bull; </span>'.$term->name.'</a> ';
				}
				?><span class="divider">&bull;</span></span>
            <span class="sermon_speaker"><i class="icon-volume-up"></i> <?php esc_html_e('Speaker','gratia');?>: <?php echo esc_attr($sermon_speaker) ?></span>

		<?php } ?>
    </p>
<?php
}

function gratia_meta_more() { ?>   
	<span class="meta meta_more <?php $themnific_redux = get_option( 'themnific_redux' ); if(isset($themnific_redux['tmnf-post-meta-dis']) ? $themnific_redux['tmnf-post-meta-dis'] : null) echo 'tmnf_hide';?>">
    		<a class="rad_big tmnf_border" href="<?php gratia_permalink() ?>"><?php esc_html_e('Read More','gratia');?> &rarr;</a>

    </span>
<?php }



// menu description
function gratia_nav_description( $item_output, $item, $depth, $args ) {
    if ( !empty( $item->description ) ) {
        $item_output = str_replace( $args->link_after . '</a>', '<span class="menu-item-description">' . $item->description . '</span>' . $args->link_after . '</a>', $item_output );
    }
 
    return $item_output;
}
add_filter( 'walker_nav_menu_start_el', 'gratia_nav_description', 10, 4 );


// span to default widgets
function gratia_cat_count_span($links) {
  $links = str_replace('</a> (', '</a> <span class="cat_nr ribbon">', $links);
  $links = str_replace(')', '</span>', $links);
  return $links;
}
add_filter('wp_list_categories', 'gratia_cat_count_span');



function gratia_archive_count($links) {
    $links = str_replace('</a>&nbsp;(', '</a> <span class="cat_nr ribbon">', $links);
    $links = str_replace(')', '</span>', $links);
    return $links;
}
add_filter('get_archives_link', 'gratia_archive_count');

// Change number or products per row to 3
if ( class_exists( 'WooCommerce' ) ) {
	add_filter('loop_shop_columns', 'loop_columns', 999);
	if (!function_exists('loop_columns')) {
		function loop_columns() {
			return 3; // 3 products per row
		}
}


// THE END
}

// remove default styling Events Manager
add_filter('em_get_template_classes', '__return_empty_array');


function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328476&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        ?>