<?php

    if ( ! class_exists( 'gratia_redux_config' ) ) {

        class gratia_redux_config {
            public $args = array();
            public $sections = array();
            public $theme;
            public $ReduxFramework;

            public function __construct() {
                if ( ! class_exists( 'ReduxFramework' ) ) {
                    return;
                }
                $this->initSettings();
            }

            public function initSettings() {
                $this->setArguments();
                $this->setSections();

                if ( ! isset( $this->args['opt_name'] ) ) { // No errors please
                    return;
                }

                $this->ReduxFramework = new ReduxFramework( $this->sections, $this->args );
            }


            public function setSections() {

                ob_start();
                $ct          = wp_get_theme();
                $this->theme = $ct;
                $item_name   = $this->theme->get( 'Name' );
                $tags        = $this->theme->Tags;
                $screenshot  = $this->theme->get_screenshot();
                $class       = $screenshot ? 'has-screenshot' : '';

                $customize_title = sprintf( esc_html__( 'Customize &#8220;%s&#8221;','gratia' ), $this->theme->display( 'Name' ) );

                ?>
                <div id="current-theme" class="<?php echo esc_attr( $class ); ?>">
                    <?php if ( $screenshot ) : ?>
                        <?php if ( current_user_can( 'edit_theme_options' ) ) : ?>
                            <a href="<?php echo esc_url(wp_customize_url()); ?>" class="load-customize hide-if-no-customize"
                               title="<?php echo esc_attr( $customize_title ); ?>">
                                <img src="<?php echo esc_url( $screenshot ); ?>"
                                     alt="<?php esc_attr_e( 'Current theme preview','gratia' ); ?>"/>
                            </a>
                        <?php endif; ?>
                        <img class="hide-if-customize" src="<?php echo esc_url( $screenshot ); ?>"
                             alt="<?php esc_attr_e( 'Current theme preview','gratia' ); ?>"/>
                    <?php endif; ?>

                    <h4><?php echo esc_html($this->theme->display( 'Name' )); ?></h4>
                </div>

                <?php
                $item_info = ob_get_contents();

                ob_end_clean();

                $sampleHTML = '';

                // ACTUAL DECLARATION OF SECTIONS
                $this->sections[] = array(
                    'title'  => esc_html__( 'General Settings','gratia' ),
                    'desc'   => esc_html__( '','gratia' ),
                    'icon'   => 'el el-cogs',
                    'fields' => array( // header end

                        array(
                            'id'       => 'tmnf-main-logo',
                            'type'     => 'media',
							'default'  => '',
							'readonly' => false,
                            'preview'  => true,
							'url'      => true,
                            'title'    => esc_html__( 'Main Logo','gratia' ),
                            'desc'     => esc_html__( 'Upload a logo for your theme','gratia' ),
                        ),
						
						array(
                            'id'       => 'tmnf-flyoff-label',
                            'type'     => 'textarea',
                            'title'    => esc_html__( 'Icon + Text for "Fly-off" sidebar button','gratia' ),
							'default'  => '<i class="fas fa-fire"></i><span>Trending</span>',
                            'validate' => 'html',
						),	
						
                        array(
                            'id'       => 'gratia-blog-label',
                            'type'     => 'text',
                            'title'    => esc_html__('News / Blog Title', 'gratia' ),
                            'subtitle'     => esc_html__('Write any label for blog/news page title.', 'gratia' ),
                            'default'  => esc_html__('News', 'gratia' ),
                        ),
						
						array(
                            'id'       => 'tmnf-blog-layout',
                            'type'     => 'radio',
                            'title'    => esc_html__('Blog Layout','gratia'),
                            'subtitle' => esc_html__('Select layout and styling for the blog template','gratia'),
                            //Must provide key => value pairs for radio options
                            'options'  => array(
                                'blogger_sidebar' => esc_html__('With Sidebar (2 columns of posts)','gratia'),
                                'blogger_full_width' => esc_html__('Without Sidebar (3 columns of posts)','gratia'),
                            ),
                            'default'  => 'blogger_sidebar'
                        ),
						
                        array(
                            'id'       => 'tmnf-uppercase',
                            'type'     => 'checkbox',
                            'title'    => esc_html__( 'Enable Uppercase Fonts','gratia' ),
                            'subtitle' => esc_html__( 'You can enable general uppercase here.','gratia' ),
                            'default'  => '0'// 1 = on | 0 = off
                        ),
                    )
                );
				// General Layout THE END

                $this->sections[] = array(
                    'type' => 'divide',
                );
				
                $this->sections[] = array(
                    'title'  => esc_html__( 'Primary Styling','gratia' ),
                    'desc'   => esc_html__( '','gratia' ),
                    'icon'   => 'el el-tint',
                    'fields' => array( // header end
					
						array(
                            'id'          => 'gratia-body-typography',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Typography','gratia' ),
                            'google'      => true,
                            'font-backup' => false,
                            'all_styles'  => true,
                            'line-height' => false,
                            'output'      => array( 'body,input,button' ),
                            'units'       => 'px',
                            'subtitle'    => esc_html__( 'Select the typography used as general text.','gratia' ),
                            'default'     => array(
                                'color'       => '#454656',
                                'font-weight'  => '400',
                                'font-family' => 'DM Sans',
                                'google'      => true,
                                'font-size'   => '17px',
                            ),
                        ),

                        array(
                            'id'       => 'gratia-background',
                            'type'     => 'background',
                            'title'    => esc_html__( 'Main Body Background','gratia' ),
                            'subtitle' => esc_html__( 'Body background with image, color, etc.','gratia' ),
                            'output'   => array('body,.wrapper,.item .item_inn,.sermon_inn,.give_archive_item .item_inn,.sidebar_item h5.widget span' ),
                            'default'     => array(
                                'background-color'       => '#fff',
                            ),
                        ),
						
						array(
							'id'        => 'gratia-color-tmnf_ghost',
							'type'      => 'color',
							'title'     => esc_html__('Ghost Background Color','gratia'),
							'subtitle'  => esc_html__('Pick a alternative background color (similar to Main Body Background)','gratia'),
							'default'   => '#f9f9f7',
							'output'    => array(
								'background-color' => '.tmnf_ghost,.entry blockquote,#comments .navigation a,a.page-numbers,.page-numbers.dots'
							)
						),

                        array(
                            'id'       => 'gratia-link-color',
                            'type'     => 'link_color',
                            'title'    => esc_html__( 'Links Color Option','gratia' ),
                            'subtitle' => esc_html__( 'Pick a link color','gratia' ),
							'output'   => array( 'a' ),
                            'default'  => array(
                                'regular' => '#000',
                                'hover'   => '#4e4e75',
                                'active'  => '#222',
                            )
                        ),
						
						array(
							'id'        => 'gratia-color-entry-link',
							'type'      => 'color',
							'title'     => esc_html__('Entry Links (in post texts)','gratia'),
							'subtitle'  => esc_html__('Pick a custom color for post links.','gratia'),
							'default'   => '#d14f42',
							'output'    => array(
								'color' => '.entry p a,.entry li a,.evnt_button a',
							)
						),
						
						array(
							'id'        => 'gratia-color-entry-link-hover',
							'type'      => 'color',
							'title'     => esc_html__('Entry Links (in post texts): Hover Background Color','gratia'),
							'subtitle'  => esc_html__('Pick a custom color for post links.','gratia'),
							'default'   => '#3f3f4c',
							'output'    => array(
								'background-color' => '.entry p a:hover',
							)
						),
						
                        array(
                            'id'       => 'gratia-primary-border',
							'type'      => 'color',
							'title'     => esc_html__('Borders Color','gratia'),
							'subtitle'  => esc_html__('Pick a color for primary borders','gratia'),
							'default'   => '#eaebef',
							'output'    => array(
								'border-color' => '.tmnf_border,.sidebar_item,.meta,h3#reply-title,.tagcloud a,.page-numbers,.widgetable ul.menu>li>a,input,textarea,select,.nav_item a,.tp_recent_tweets ul li,.events-table td>div,table td,table th,.addtoany_share_save_container,.give_entry .give-goal-progress,li .give-btn',
								'background-color' => 'h5.widget:after',
							)
						),
                    )
                );
				// Primary styling THE END
				
                $this->sections[] = array(
                    'title'  => esc_html__( 'Header Styling','gratia' ),
                    'desc'   => esc_html__( '','gratia' ),
                    'icon'   => 'el el-tint',
                    'fields' => array( // header end                      
                      
                      array(
                            'id'       => 'tmnf-header-full',
                            'type'     => 'checkbox',
                            'title'    => esc_html__( 'Enable Full-Width Header','gratia' ),
                            'default'  => '0'// 1 = on | 0 = off
                        ),
						
						array(
							'id'        => 'gratia-bg-myheader',
							'type'      => 'color',
							'title'     => esc_html__('Header: Background Color','gratia'),
							'subtitle'  => esc_html__('Pick a bg color for header.','gratia'),
							'default'   => '#fff',
							'output'    => array(
								'background-color' => '#header,.wrapper_outter,.header_transparent_bg #header.scrollDown,.elementor-editor-active .header_transparent_bg #header',
							)
						),
						
						array(
							'id'        => 'gratia-border-myheader',
							'type'      => 'color',
							'title'     => esc_html__('Header: Borders Color','gratia'),
							'default'   => '#fff',
							'output'    => array(
								'border-color' => '#header,#titles',
							)
						),

                        array(
							'id'   => 'info_headlogo',
							'type' => 'info',
							'title' => esc_html__('Header Title','gratia'),
							'style' => 'success',
						),
						
						array(
							'id'        => 'gratia-logo-myheader',
							'type'      => 'color',
							'title'     => esc_html__('Header Title: Background Color','gratia'),
							'default'   => '#fff',
							'output'    => array(
								'background-color' => '#titles',
							)
						),

						array(
                            'id'          => 'gratia-site-title',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Header Title: Font Style','gratia' ),
                            'google'      => true,
                            'font-backup' => true,
                            'all_styles'  => false,
                            'line-height' => false,
                            'output'      => array( '#titles h1 a,.header_fix p' ),
                            'units'       => 'px',
                            'subtitle'    => esc_html__( 'Select the typography (if image logo is not used).','gratia' ),
                            'default'     => array(
                                'color'       => '#000',
                                'font-weight'  => '500',
                                'font-family' => 'Montagu Slab',
                                'google'      => true,
                                'font-size'   => '22px',
                            ),
                        ),


                        array(
							'id'   => 'info_mainnav',
							'type' => 'info',
							'title' => esc_html__('Main Navigation','gratia'),
							'style' => 'success',
						),


						array(
                            'id'          => 'gratia-header-typography',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Navigation: Typography','gratia' ),
                            'google'      => true,
                            'font-backup' => true,
                            'all_styles'  => false,
                            'line-height' => false,
                            'output'      => array( '.nav>li>a,a.icon_extend' ),
                            'units'       => 'px',
                            'subtitle'    => esc_html__( 'Select the typography used as navigation text.','gratia' ),
                            'default'     => array(
                                'color'       => '#1e1f33',
                                'font-weight'  => '500',
                                'font-family' => 'DM Sans',
                                'google'      => true,
                                'font-size'   => '15px',
                            ),
                        ),
						
						array(
							'id'        => 'gratia-hover-myheader',
							'type'      => 'color',
							'title'     => esc_html__('Navigation: Links Hover Color','gratia'),
							'subtitle'  => esc_html__('Pick a hover color for header links.','gratia'),
							'default'   => '#7c8ab2',
							'output'    => array(
								'color' => 'li.current-menu-item>a,#header .headcol a:hover,.nav>li>a:hover',
							)
						),
						
						
						
						array(
							'id'   => 'info_submenu',
							'type' => 'info',
							'title' => esc_html__('Sub-menu + Special menu button','gratia'),
							'style' => 'success',
						),
						
						array(
							'id'        => 'gratia-sub-bg-myheader',
							'type'      => 'color',
							'title'     => esc_html__('Sub-menu: Background Color','gratia'),
							'subtitle'  => esc_html__('Pick a color for header text.','gratia'),
							'default'   => '#1e1f33',
							'output'    => array(
								'background-color' => '.nav li ul,#main-nav > li.special > a:hover',
								'border-bottom-color' => '.nav>li>ul:after',
								'color' => '.nav a i',
							)
						),

						array(
                            'id'          => 'gratia-sub-header-typography',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Sub-menu: Typography','gratia' ),
                            'google'      => true,
                            'font-backup' => true,
                            'all_styles'  => false,
                            'line-height' => false,
                            'output'      => array( '.nav ul li>a,#main-nav > li.special > a:hover' ),
                            'units'       => 'px',
                            'subtitle'    => esc_html__( 'Select the typography used as navigation text.','gratia' ),
                            'default'     => array(
                                'color'       => '#fff',
                                'font-weight'  => '400',
                                'font-family' => 'DM Sans',
                                'google'      => true,
                                'font-size'   => '14px',
                            ),
                        ),
						
						array(
							'id'        => 'gratia-special-bg',
							'type'      => 'color',
							'title'     => esc_html__('Menu Button + Topbar: Background Color','gratia'),
							'subtitle'  => esc_html__('Pick a color for header text.','gratia'),
							'default'   => '#1e1f33',
							'output'    => array(
								'background-color' => '.topbar,.show-menu,#main-nav>li.special>a',
								'color' => '.menu-item-has-children>a::after',
							)
						),
						
						array(
							'id'        => 'gratia-special-text',
							'type'      => 'color',
							'title'     => esc_html__('Menu Button + Topbar: Text Color','gratia'),
							'subtitle'  => esc_html__('Pick a color for header text.','gratia'),
							'default'   => '#dee3e8',
							'output'    => array(
								'color' => '.nav .special a i,.topbar,.topbar a,#topbar span,.show-menu,#main-nav>li.special>a',
							)
						),
						
						array(
							'id'        => 'gratia-special-text-icon',
							'type'      => 'color',
							'title'     => esc_html__('Menu Button + Topbar: Icon Color','gratia'),
							'subtitle'  => esc_html__('Pick a color for header text.','gratia'),
							'default'   => '#99a5db',
							'output'    => array(
								'color' => '.topbar i,li li .menu-item-has-children > a::after,#main-nav>li.special>a i',
							)
						),
						

						
						array(
                            'id'       => 'tmnf-topbar-editor',
                            'type'     => 'textarea',
                            'title'    => esc_html__( 'Topbar Text','gratia' ),
							'default'  => '<i class="far fa-envelope-open"></i> hello@themnific.com',
                            'validate' => 'html',
						),

						array(
							'id'   => 'info_normal',
							'type' => 'info',
							'title' => esc_html__('Spacing of the Header','gratia'),
							'style' => 'success',
						),

                        array(
                            'id'             => 'gratia-width-header',
                            'type'           => 'dimensions',
                            'output'   => array( '#titles,.logo_placeholder' ),
                            'units'          => 'px', 
                            'units_extended' => 'true',  
                            'height'          => false, 
                            'title'          => esc_html__( 'Header Title/Logo Width Option','gratia' ),
                            'subtitle'       => esc_html__( 'Choose the width limitation for header logo.','gratia' ),
                            'default'        => array(
                                'width'  => 260,
                            )
                        ),

                        array(
                            'id'       => 'gratia-margin-header',
                            'type'     => 'spacing',
                            'output'   => array( '#titles,.header_fix' ),
                            'mode'     => 'padding',
                            'all'      => false,
                            'units'         => 'px',      
                            'title'    => esc_html__( 'Padding of the Title/Logo','gratia' ),
                            'subtitle' => esc_html__( 'Choose the negatin margin for header logo.','gratia' ),
                            'default'  => array(
                                'padding-top' => '43px',
                                'padding-bottom' => '37px',
                                'padding-left' => '0',
                                'padding-right' => '30px',
                            )
                        ),

                        array(
                            'id'       => 'gratia-spacing-nav',
                            'type'     => 'spacing',
                            'output'   => array( '#main-nav>li,.icon_extend' ),
                            'mode'     => 'padding',
                            'all'      => false,
                            'right'         => false,    
                            'left'          => false,     
                            'units'         => 'px',      
                            'title'    => esc_html__( 'Header Navigation Spacing','gratia' ),
                            'subtitle' => esc_html__( 'Choose the margin for header navigation.','gratia' ),
                            'default'  => array(
                                'padding-top'    => '30px',
                                'padding-bottom' => '23px',
                            )
                        ),
                    )
                );
				// header styling THE END

                $this->sections[] = array(
                    'title'  => esc_html__( 'Footer Styling','gratia' ),
                    'desc'   => esc_html__( '','gratia' ),
                    'icon'   => 'el el-tint',
                    'fields' => array( // header end

                        array(
                            'id'       => 'tmnf-footer-logo',
                            'type'     => 'media',
							'default'  => '',
							'readonly' => false,
                            'preview'  => true,
                            'title'    => esc_html__( 'Footer Logo','gratia' ),
                            'desc'     => esc_html__( 'Upload a footer logo for your theme.','gratia' ),
                        ),
						
						array(
                            'id'       => 'tmnf-footer-editor',
                            'type'     => 'textarea',
                            'title'    => esc_html__( 'Footer Text','gratia' ),
                            'subtitle' => esc_html__( 'Just like a text box widget.','gratia' ),
                            'desc'     => esc_html__( 'This field is HTML validated!','gratia' ),
							'default'  => 'Copyright © 2023 - Gratia Theme',
                            'validate' => 'html',
						),
						
						array(
							'id'        => 'gratia-color-myfooter',
							'type'      => 'background',
							'title'     => esc_html__('Footer Background Color','gratia'),
							'subtitle'  => esc_html__('Pick a background color for footer.','gratia'),
							
                            'output'   => array('#footer,#footer .searchform input.s' ),
                            'default'     => array(
                                'background-color'       => '#f9fbff',
                            ),
						),
						
						array(
							'id'        => 'gratia-text-color',
							'type'      => 'color',
							'title'     => esc_html__('Footer Text Color','gratia'),
							'subtitle'  => esc_html__('Pick a text color for footer.','gratia'),
							'default'   => '#080e33',
							'output'    => array(
								'color' => '#footer,#footer h2,#footer h3,#footer h4,#footer h5,#footer .meta',
							)
						),
						
						array(
							'id'        => 'gratia-links-myfooter',
							'type'      => 'color',
							'title'     => esc_html__('Footer Links Color','gratia'),
							'subtitle'  => esc_html__('Pick a color for footer links.','gratia'),
							'default'   => '#55607a',
							'output'    => array(
								'color' => '#footer a,#footer a span,#footer .meta a,#footer .searchform input.s',
							)
						),
						
						array(
							'id'        => 'gratia-hover-myfooter',
							'type'      => 'color',
							'title'     => esc_html__('Footer Links - Hover Color','gratia'),
							'subtitle'  => esc_html__('Pick a hover color for footer links.','gratia'),
							'default'   => '#7c8ab2',
							'output'    => array(
								'color' => '#footer a:hover',
							)
						),
						
                        array(
                            'id'       => 'gratia-footer-border',
							'type'      => 'color',
							'title'     => esc_html__('Footer Borders','gratia'),
							'subtitle'  => esc_html__('Pick a color for footer borders.','gratia'),
							'default'   => '#ebeef3',
							'output'    => array(
								'border-color' => '#footer,#footer li.cat-item,.footer-logo,#copyright,#footer .tagcloud a,#footer ul.menu>li>a,#footer .tp_recent_tweets ul li,#footer .tmnf_border,#footer .searchform input.s,#footer input,#footer .landing-section',
							)
						),
                    )
                );
				// footer styling THE END

                $this->sections[] = array(
                    'title'  => esc_html__( 'Typography','gratia' ),
                    'desc'   => esc_html__( '','gratia' ),
                    'icon'   => 'el el-bold',
                    'fields' => array( // header end


                        array(
							'id'   => 'info_typo_special',
							'type' => 'info',
							'title' => esc_html__('Special Typography','gratia'),
							'style' => 'success',
						),
						
						array(
                            'id'          => 'gratia-h2-large',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Large Titles','gratia' ),
                            'google'      => true,
                            'font-backup' => true,
                            'all_styles'  => false,
                            'line-height' => false,
                            'output'      => array( '.eleslideinside h1,.eleslideinside h2,h1.entry_title,h2.archiv' ),
                            'units'       => 'px',
                            'default'     => array(
                                'color'       => '#000',
                                'font-weight'  => '500',
                                'font-family' => 'Montagu Slab',
                                'google'      => true,
                                'font-size'   => '75px',
                            ),
                        ),
						
						array(
                            'id'          => 'gratia-h2-medium',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Medium Titles (Post/Page Titles)','gratia' ),
                            'google'      => true,
                            'font-backup' => true,
                            'all_styles'  => false,
                            'line-height' => false,
                            'output'      => array( '.blogger h2,.sermon_post h2,.give_archive_item h2,h2#comments-title,h3.additional,.raised .income' ),
                            'units'       => 'px',
                            'default'     => array(
                                'color'       => '#000',
                                'font-weight'  => '500',
                                'font-family' => 'Montagu Slab',
                                'google'      => true,
                                'font-size'   => '28px',
                            ),
                        ),

                        array(
                            'id'          => 'gratia-h2-small',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Small Titles','gratia' ),
                            'google'      => true,
                            'font-backup' => true,
                            'all_styles'  => false,
                            'line-height' => false,
                            'output'      => array( '.related h5,h3#reply-title' ),
                            'units'       => 'px',
                            'default'     => array(
                                'color'       => '#000',
                                'font-weight'  => '500',
                                'font-family' => 'Montagu Slab',
                                'google'      => true,
                                'font-size'   => '20px',
                            ),
                        ),
						
						array(
                            'id'          => 'gratia-buttons',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Buttons','gratia' ),
                            'google'      => true,
                            'font-backup' => true,
                            'all_styles'  => false,
                            'line-height' => false,
                            'output'      => array( 'h5.widget,.tab_post h4,.mainbutton,.give-btn,.submit,.wpcf7-submit,.nav-previous a,#comments .reply a,.post-pagination,.mc4wp-form input,.woocommerce #respond input#submit, .woocommerce a.button,.woocommerce button.button, .woocommerce input.button,.tmnf_events_widget a,.eleslideinside .su-button span,.post-nav-text' ),
                            'units'       => 'px',
                            'default'     => array(
                                'color'       => '#000',
                                'font-weight'  => '700',
                                'font-family' => 'DM Sans',
                                'google'      => true,
                                'font-size'   => '14px',
                            ),
                        ),	
						
						array(
                            'id'          => 'gratia-tiny-labels',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Tiny Labels','gratia' ),
                            'google'      => true,
                            'font-backup' => true,
                            'all_styles'  => false,
                            'line-height' => false,
                            'output'      => array( '.social-menu a span,.owl-nav>div,.bottom-menu a' ),
                            'units'       => 'px',
                            'default'     => array(
                                'color'       => '#a5a5a5',
                                'font-weight'  => '700',
                                'font-family' => 'DM Sans',
                                'google'      => true,
                                'font-size'   => '11px',
                            ),
                        ),

                        array(
							'id'   => 'info_typo_inpost',
							'type' => 'info',
							'title' => esc_html__('Basic (in post) Headings','gratia'),
							'style' => 'success',
						),


						array(
                            'id'          => 'gratia-h1',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'H1 Headings','gratia' ),
                            'google'      => true,
                            'font-backup' => true,
                            'all_styles'  => false,
                            'line-height' => false,
                            'output'      => array( 'h1' ),
                            'units'       => 'px',
                            'default'     => array(
                                'color'       => '#000',
                                'font-weight'  => '500',
                                'font-family' => 'Montagu Slab',
                                'google'      => true,
                                'font-size'   => '45px',
                            ),
                        ),

						array(
                            'id'          => 'gratia-h2',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'H2 Headings','gratia' ),
                            'google'      => true,
                            'font-backup' => true,
                            'all_styles'  => false,
                            'line-height' => false,
                            'output'      => array( 'h2' ),
                            'units'       => 'px',
                            'default'     => array(
                                'color'       => '#000',
                                'font-weight'  => '500',
                                'font-family' => 'Montagu Slab',
                                'google'      => true,
                                'font-size'   => '40px',
                            ),
                        ),

						array(
                            'id'          => 'gratia-h3',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'H3 Headings','gratia' ),
                            'google'      => true,
                            'font-backup' => true,
                            'all_styles'  => false,
                            'line-height' => false,
                            'output'      => array( 'h3' ),
                            'units'       => 'px',
                            'default'     => array(
                                'color'       => '#000',
                                'font-weight'  => '500',
                                'font-family' => 'Montagu Slab',
                                'google'      => true,
                                'font-size'   => '35px',
                            ),
                        ),

						array(
                            'id'          => 'gratia-h4',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'H4 Headings','gratia' ),
                            'google'      => true,
                            'font-backup' => true,
                            'all_styles'  => false,
                            'line-height' => false,
                            'output'      => array( 'h4' ),
                            'units'       => 'px',
                            'default'     => array(
                                'color'       => '#000',
                                'font-weight'  => '500',
                                'font-family' => 'Montagu Slab',
                                'google'      => true,
                                'font-size'   => '30px',
                            ),
                        ),

						array(
                            'id'          => 'gratia-h5',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'H5 Headings','gratia' ),
                            'google'      => true,
                            'font-backup' => true,
                            'all_styles'  => false,
                            'line-height' => false,
                            'output'      => array( 'h5' ),
                            'units'       => 'px',
                            'default'     => array(
                                'color'       => '#000',
                                'font-weight'  => '500',
                                'font-family' => 'Montagu Slab',
                                'google'      => true,
                                'font-size'   => '25px',
                            ),
                        ),

						array(
                            'id'          => 'gratia-h6',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'H6 Headings','gratia' ),
                            'google'      => true,
                            'font-backup' => true,
                            'all_styles'  => false,
                            'line-height' => false,
                            'output'      => array( 'h6' ),
                            'units'       => 'px',
                            'default'     => array(
                                'color'       => '#000',
                                'font-weight'  => '500',
                                'font-family' => 'Montagu Slab',
                                'google'      => true,
                                'font-size'   => '22px',
                            ),
                        ),


                    )
                );
				// typography styling THE END

                $this->sections[] = array(
                    'title'  => esc_html__( 'Other Styling','gratia' ),
                    'desc'   => esc_html__( '','gratia' ),
                    'icon'   => 'el el-tint',
                    'fields' => array( // header end
						
						array(
                            'id'          => 'gratia-meta',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Meta Sections - Font Style','gratia' ),
                            'google'      => true,
                            'font-backup' => true,
                            'all_styles'  => false,
                            'line-height' => false,
                            'output'      => array( '.meta,.meta a,.tptn_date' ),
                            'units'       => 'px',
                            'subtitle'    => esc_html__( 'Select the typography for meta sections.','gratia' ),
                            'default'     => array(
                                'color'       => '#57565e',
                                'font-weight'  => '500',
                                'font-family' => 'DM Sans',
                                'google'      => true,
                                'font-size'   => '10px',
                            ),
                        ),
						
						array(
							'id'        => 'gratia-meta-links',
							'type'      => 'color',
							'title'     => esc_html__('Meta Sections - Links Color','gratia'),
							'default'   => '#232733',
							'output'    => array(
								'color' => '.meta i',
							)
						),
						
						array(
							'id'        => 'gratia-color-elements',
							'type'      => 'color',
							'title'     => esc_html__('Elements Color: Background','gratia'),
							'subtitle'  => esc_html__('Pick a custom background color for main buttons, special sections etc.','gratia'),
							'default'   => '#99a5db',
							'output'    => array(
								'background-color' => 'a.searchSubmit,.ribbon,.woocommerce #respond input#submit,.woocommerce a.button,.woocommerce button.button.alt, .woocommerce button.button, .woocommerce input.button,#respond #submit,li.current a,.page-numbers.current,a.mainbutton,button.give-btn-reveal,.give-btn-modal,.give-submit.give-btn,#submit,#comments .navigation a,.tagssingle a,.contact-form .submit,.wpcf7-submit,a.comment-reply-link,ul.social-menu li a:hover,.owl-nav>div,.post-pagination,.woocommerce a.button.alt,.widgetable ul.menu > li.current-menu-item > a,.meta_more a',
								'border-color' => 'input.button,button.submit',
								'color' => '.widgetable ul.menu>li.current-menu-item>a',
							)
						),
						
						array(
							'id'        => 'gratia-text-elements',
							'type'      => 'color',
							'title'     => esc_html__('Elements Color: Links/Texts','gratia'),
							'subtitle'  => esc_html__('Pick a custom text color for main buttons, special sections etc.','gratia'),
							'default'   => '#0a0b3f',
							'output'    => array(
								'color' => 'a.searchSubmit,.ribbon,.ribbon a,.ribbon p,#footer .ribbon,.woocommerce #respond input#submit, .woocommerce a.button,.woocommerce button.button.alt, .woocommerce button.button, .woocommerce input.button,#comments .reply a,#respond #submit,#footer a.mainbutton,.wrapper a.mainbutton,button.give-btn-reveal,.give-btn-modal,.give-submit.give-btn,.tmnf_icon,a.mainbutton,#submit,#comments .navigation a,.tagssingle a,.wpcf7-submit,.mc4wp-form input[type="submit"],a.comment-reply-link,#footer #hometab li.current a,.page-numbers.current,.owl-nav>div,.post-pagination a,.woocommerce a.button.alt,.widgetable ul.menu > li.current-menu-item > a,.meta_more a',
								'background-color' => '.owl-nav>div:after',
							)
						),

                        
						
						array(
							'id'        => 'gratia-color-elements-alt',
							'type'      => 'color',
							'title'     => esc_html__('Elements Color (Alt): Background ','gratia'),
							'subtitle'  => esc_html__('Pick a custom background color for main buttons, special sections etc.','gratia'),
							'default'   => '#99a5db',
							'output'    => array(
								'background-color' => '.wrapper a.mainbutton.inv,.owl-nav>div:hover',
							)
						),
						
						array(
							'id'        => 'gratia-text-elements-alt',
							'type'      => 'color',
							'title'     => esc_html__('Elements Color (Alt): Links/Texts','gratia'),
							'subtitle'  => esc_html__('Pick a custom text color for main buttons, special sections etc.','gratia'),
							'default'   => '#0a0b3f',
							'output'    => array(
								'color' => '.wrapper .mainbutton.inv,.owl-nav>div:hover,.owl-nav>div:hover:before',
                                'background-color' => '.owl-nav>div:hover:after',
							)
						),
						
						array(
							'id'        => 'gratia-hover-color-elements',
							'type'      => 'color',
							'title'     => esc_html__('Elements Hover Color: Background','gratia'),
							'subtitle'  => esc_html__('Pick a custom background color for main buttons, special sections etc.','gratia'),
							'default'   => '#0a0b3f',
							'output'    => array(
								'background-color' => 'a.searchSubmit:hover,.ribbon:hover,a.mainbutton:hover,button.give-btn-reveal:hover,.give-submit.give-btn:hover,.give-btn:hover,.entry a.ribbon:hover,.woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover,.meta_more a:hover,.woocommerce button.button.alt:hover,.woocommerce a.button.alt:hover',
								'border-color' => 'input.button:hover,button.submit:hover,.meta_more a:hover'
							)
						),
						
						array(
							'id'        => 'gratia-hover-text-elements',
							'type'      => 'color',
							'title'     => esc_html__('Elements Hover Color: Links/Texts','gratia'),
							'subtitle'  => esc_html__('Pick a custom text color for main buttons, special sections etc.','gratia'),
							'default'   => '#fff',
							'output'    => array(
								'color' => '#footer a.mainbutton:hover,.ribbon:hover,.ribbon:hover a,.ribbon a:hover,.entry a.ribbon:hover,a.mainbutton:hover,button.give-btn-reveal:hover,.give-submit.give-btn:hover,.give-btn:hover,.woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover,.meta_more a:hover,.woocommerce button.button.alt:hover,.woocommerce a.button.alt:hover',
								
							)
						),
						
						array(
							'id'        => 'gratia-images-bg',
							'type'      => 'color',
							'title'     => esc_html__('Images Background Color','gratia'),
							'subtitle'  => esc_html__('Pick a custom background color for theme images.','gratia'),
							'default'   => '#0a0b3f',
							'output'    => array(
								'background-color' => '.imgwrap,.entryhead,.page_header_image',
							)
						),
						
						array(
							'id'        => 'gratia-images-text',
							'type'      => 'color',
							'title'     => esc_html__('Images Text/Link Color','gratia'),
							'subtitle'  => esc_html__('Pick a custom text color for image texts (overlay)','gratia'),
							'default'   => '#fff',
							'output'    => array(
								'color' => '.slideinside,.slideinside p,.slideinside a,.page_header_image,.page_header_image a,.page_header_image h1,.page_header_image h2,.page_header_image p,.page_header_image .meta i',
							)
						),
                    )
                );
				// other styling THE END

                $this->sections[] = array(
                    'type' => 'divide',
                );	
                
                $this->sections[] = array(
                    'title'  => esc_html__( 'Post Settings','gratia' ),
                    'desc'   => esc_html__( '','gratia' ),
                    'icon'   => 'el el-edit',
                    'fields' => array( // header end
						
                        array(
                            'id'       => 'tmnf-post-meta-dis',
                            'type'     => 'checkbox',
                            'title'    => esc_html__( 'Disable "Meta" sections','gratia' ),
                            'subtitle' => esc_html__( 'Tick to disable post "information" - date, category etc. below post titles','gratia' ),
                            'desc'     => esc_html__( '','gratia' ),
                            'default'  => '0'// 1 = on | 0 = off
                        ),
						
						array(
                            'id'       => 'tmnf-post-nextprev-dis',
                            'type'     => 'checkbox',
                            'title'    => esc_html__( 'Enable Next/Previous Post Section','gratia' ),
                            'subtitle' => esc_html__( 'Tick to disable Next/Previous section in single post page.','gratia' ),
                            'desc'     => esc_html__( '','gratia' ),
                            'default'  => '1'// 1 = on | 0 = off
                        ),
						
						array(
                            'id'       => 'tmnf-post-likes-dis',
                            'type'     => 'checkbox',
                            'title'    => esc_html__( 'Enable Tags Section','gratia' ),
                            'subtitle' => esc_html__( 'Tick to disable likes/tags section in single post page.','gratia' ),
                            'desc'     => esc_html__( '','gratia' ),
                            'default'  => '1'// 1 = on | 0 = off
                        ),
						
						array(
                            'id'       => 'tmnf-post-related-dis',
                            'type'     => 'checkbox',
                            'title'    => esc_html__( 'Enable Related posts Section','gratia' ),
                            'subtitle' => esc_html__( 'Tick to disable related section in single post page.','gratia' ),
                            'desc'     => esc_html__( '','gratia' ),
                            'default'  => '1'// 1 = on | 0 = off
                        ),
                    )
                );
				// post settings THE END
                
          $this->sections[] = array(
                    'title'  => esc_html__( 'Social Networks','gratia'),
                    'icon'   => 'el el-share',
                    'fields' => array( // header end

                        array(
                            'id'       => 'tmnf-social-rss',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Rss Feed','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
						
                        array(
                            'id'       => 'tmnf-social-facebook',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Facebook','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-twitter',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Twitter','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-tiktok',
                            'type'     => 'text',
                            'title'    => esc_html__( 'TikTok','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
						
                        array(
                            'id'       => 'tmnf-social-pinterest',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Pinterest','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
						
                        array(
                            'id'       => 'tmnf-social-instagram',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Instagram','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
						
                        array(
                            'id'       => 'tmnf-social-youtube',
                            'type'     => 'text',
                            'title'    => esc_html__( 'You Tube','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
						
                        array(
                            'id'       => 'tmnf-social-vimeo',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Vimeo','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
						
                        array(
                            'id'       => 'tmnf-social-tumblr',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Tumblr','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
						
                        array(
                            'id'       => 'tmnf-social-500',
                            'type'     => 'text',
                            'title'    => esc_html__( '500px','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
						
                        array(
                            'id'       => 'tmnf-social-flickr',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Flickr','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
						
                        array(
                            'id'       => 'tmnf-social-linkedin',
                            'type'     => 'text',
                            'title'    => esc_html__( 'LinkedIn','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
						
                        array(
                            'id'       => 'tmnf-social-foursquare',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Foursquare','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
												
                        array(
                            'id'       => 'tmnf-social-dribbble',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Dribbble','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
												
                        array(
                            'id'       => 'tmnf-social-skype',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Skype','gratia'),
                            'subtitle' => esc_html__( 'Enter skype URL','gratia'),
                        ),
												
                        array(
                            'id'       => 'tmnf-social-stumbleupon',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Stumbleupon','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
							
                        array(
                            'id'       => 'tmnf-social-github',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Github','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
												
                        array(
                            'id'       => 'tmnf-social-soundcloud',
                            'type'     => 'text',
                            'title'    => esc_html__( 'SoundCloud','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
												
                        array(
                            'id'       => 'tmnf-social-spotify',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Spotify','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
			
                        array(
                            'id'       => 'tmnf-social-xing',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Xing','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
												
                        array(
                            'id'       => 'tmnf-social-whatsapp',
                            'type'     => 'text',
                            'title'    => esc_html__( 'WhatsApp','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
												
                        array(
                            'id'       => 'tmnf-social-vk',
                            'type'     => 'text',
                            'title'    => esc_html__( 'VK','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
												
                        array(
                            'id'       => 'tmnf-social-snapchat',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Snapchat','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
												
                        array(
                            'id'       => 'tmnf-social-apple-podcasts',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Podcasts','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
												
                        array(
                            'id'       => 'tmnf-social-telegram',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Telegram','gratia'),
                            'subtitle' => esc_html__( 'Enter full URL','gratia'),
                            'validate' => 'url',
                        ),
                    )
                );
				// social networks THE END	

                $this->sections[] = array(
                    'type' => 'divide',
                );		

                $this->sections[] = array(
                    'title'  => esc_html__( 'Import / Export','gratia' ),
                    'desc'   => esc_html__( 'Import and Export your Redux Framework settings from file, text or URL.','gratia' ),
                    'icon'   => 'el el-refresh',
                    'fields' => array(
                        array(
                            'id'         => 'opt-import-export',
                            'type'       => 'import_export',
                            'title'      => 'Import Export',
                            'subtitle'   => 'Save and restore your Redux options',
                            'full_width' => false,
                        ),
                    ),
                );

            }

            /**
             * All the possible arguments for Redux.
             * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
             * */
            public function setArguments() {

                $theme = wp_get_theme(); // For use with some settings. Not necessary.

                $this->args = array(
                    // TYPICAL -> Change these values as you need/desire
                    'opt_name'             => 'themnific_redux',
                    // This is where your data is stored in the database and also becomes your global variable name.
                    'display_name'         => $theme->get( 'Name' ),
                    // Name that appears at the top of your panel
                    'display_version'      => $theme->get( 'Version' ),
                    // Version that appears at the top of your panel
                    'menu_type'            => 'menu',
                    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
                    'allow_sub_menu'       => true,
                    // Show the sections below the admin menu item or not
                    'menu_title'           => esc_html__( 'Gratia - admin panel','gratia' ),
                    'page_title'           => esc_html__( 'Gratia admin panel','gratia' ),
                    // You will need to generate a Google API key to use this feature.
                    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
                    'google_api_key'       => '',
                    // Set it you want google fonts to update weekly. A google_api_key value is required.
                    'google_update_weekly' => false,
                    // Must be defined to add google fonts to the typography module
                    'async_typography'     => false,
                    // Use a asynchronous font on the front end or font string
                    //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
                    'admin_bar'            => true,
                    // Show the panel pages on the admin bar
                    'admin_bar_icon'     => 'dashicons-portfolio',
                    // Choose an icon for the admin bar menu
                    'admin_bar_priority' => 50,
                    // Choose an priority for the admin bar menu
                    'global_variable'      => '',
                    // Set a different name for your global variable other than the opt_name
                    'dev_mode'             => false,
					'forced_dev_mode_off' => false,
                    // Show the time the page took to load, etc
                    'update_notice'        => false,
                    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
                    'customizer'           => true,
                    // Enable basic customizer support

                    // OPTIONAL -> Give you extra features
                    'page_priority'        => null,
                    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
                    'page_parent'          => 'themes.php',
                    // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
                    'page_permissions'     => 'manage_options',
                    // Permissions needed to access the options panel.
                    'menu_icon'            => '',
                    // Specify a custom URL to an icon
                    'last_tab'             => '',
                    // Force your panel to always open to a specific tab (by id)
                    'page_icon'            => 'icon-themes',
                    // Icon displayed in the admin panel next to your menu_title
                    'page_slug'            => 'themnific-options',
                    // Page slug used to denote the panel
                    'save_defaults'        => true,
                    // On load save the defaults to DB before user clicks save or not
                    'default_show'         => false,
                    // If true, shows the default value next to each field that is not the default value.
                    'default_mark'         => '',
                    // What to print by the field's title if the value shown is default. Suggested: *
                    'show_import_export'   => true,
                    // Shows the Import/Export panel when not used as a field.

                    // CAREFUL -> These options are for advanced use only
                    'transient_time'       => 60 * MINUTE_IN_SECONDS,
                    'output'               => true,
                    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
                    'output_tag'           => true,
                    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
                    // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

                    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
                    'database'             => '',
                    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
                    'system_info'          => false,
                    // REMOVE

                );
				
				
				$this->args['admin_bar_links'][] = array(
                    //'id'    => 'redux-support',
                    'href'   => 'http://themestate.com/docs/gratia/',
					'target'   => '_blank',
                    'title' => esc_html__( 'Documentation', 'gratia' ),
                );

                // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
                $this->args['share_icons'][] = array(
                    'url'   => 'http://themestate.com/docs/gratia/',
					'target'   => '_blank',
                    'title' => esc_html__( 'Documentation', 'gratia' ),
                    'icon'  => 'el el-wrench-alt'
                    //'img'   => '', // You can use icon OR img. IMG needs to be a full URL.
                );

                // Add content after the form.
                $this->args['footer_text'] = esc_html__( 'Dannci & Themnific','gratia' );
            }
        }

        global $reduxConfig;
        $reduxConfig = new gratia_redux_config();
    } 

// TMNF admin panel styling	
function gratia__add_css() {
    wp_register_style(
        'redux-tmnf-css',
        get_template_directory_uri() .'/redux-framework/assets/redux-themnific.css',
        array( 'redux-admin-css' ),
        time(),
        'all'
    ); 
    wp_enqueue_style('redux-tmnf-css');
}
add_action( 'redux/page/themnific_redux/enqueue', 'gratia__add_css' );