<?php
add_action('widgets_init', 'sermonaddons_blog_list');

function sermonaddons_blog_list()
{
	register_widget('sermonaddons_blog_list');
}

class sermonaddons_blog_list extends WP_Widget {
	
	public function __construct() {
		$widget_ops = array('classname' => 'sermonaddons_blog_list', 'description' => esc_html__('!!Posts block for homepage only!!','sermonaddons'));
       	parent::__construct(false, esc_html__('Themnific: Blog (for homepage)','sermonaddons'),$widget_ops);  
	}
	
	function widget($args, $instance)
	{
		extract($args);
		
		$layout = esc_attr($instance['layout']);
		$post_type = 'all';
		$categories = isset( $instance['categories'] ) ? esc_attr( $instance['categories'] ) : '';
		$posts = isset( $instance['posts'] ) ? esc_attr( $instance['posts'] ) : '';
		$offset_posts = isset( $instance['offset_posts'] ) ? esc_attr( $instance['offset_posts'] ) : '';
		$archive_label = isset( $instance['archive_label'] ) ? esc_attr( $instance['archive_label'] ) : '';
		$archive_link = isset( $instance['archive_link'] ) ? esc_attr( $instance['archive_link'] ) : '';
		
		echo wp_kses_post($before_widget);
		?>
		
		<?php
		$post_types = get_post_types();
		unset($post_types['page'], $post_types['attachment'], $post_types['revision'], $post_types['nav_menu_item']);
		
		if($post_type == 'all') {
			$post_type_array = $post_types;
		} else {
			$post_type_array = $post_type;
		}
		?>
        
        <div class="widget_block">
            
			<?php
			$recent_posts = new WP_Query(array(
				'showposts' => $posts,
				'ignore_sticky_posts' => 1,
				'cat' => $categories,
				'offset' => esc_attr($offset_posts),
				'post_status' => 'publish'
			));
			
			?>
            <div class="sermon_page sermon_wrap layout_<?php echo esc_attr($layout); ?>">
			<?php  while($recent_posts->have_posts()): $recent_posts->the_post(); ?>

            	<?php get_template_part('/post-types/post-classic-mag'); ?>

			<?php endwhile;wp_reset_postdata(); ?>
			</div>
            
            
            <?php if ($archive_link == "") {} else {?>
				
					<a class="mainbutton" href="<?php echo esc_url($archive_link) ?>"><?php echo esc_html($archive_label) ?>  &rarr;</a>
				
			<?php }?>
            
			<div class="clearfix"></div>
            
        </div>
		
		<?php
		echo wp_kses_post($after_widget);
	}
	
	function update($new_instance, $old_instance)
	{
		$instance = $old_instance;
		
		$instance['layout'] = $new_instance['layout'];
		$instance['post_type'] = 'all';
		$instance['categories'] = $new_instance['categories'];
		$instance['posts'] = sanitize_text_field($new_instance['posts']);
		$instance['offset_posts'] = sanitize_text_field($new_instance['offset_posts']);
		$instance['archive_label'] = sanitize_text_field($new_instance['archive_label']);
		$instance['archive_link'] = sanitize_text_field($new_instance['archive_link']);
		
		return $instance;
	}

	function form($instance)
	{
		$defaults = array( 'post_type' => 'all', 'categories' => 'all', 'posts' => 4, 'layout' => 'col_3','offset_posts' => '','archive_label' => '','archive_link' => '');
		$instance = wp_parse_args((array) $instance, $defaults); ?>

		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('categories')); ?>"><?php esc_html_e('Filter by Category','sermonaddons'); ?></label> 
			<select id="<?php echo esc_attr($this->get_field_id('categories')); ?>" name="<?php echo esc_attr($this->get_field_name('categories')); ?>" class="widefat categories" style="width:100%;">
				<option value='all' <?php if ('all' == $instance['categories']) echo 'selected="selected"'; ?>>all categories</option>
				<?php $categories = get_categories('hide_empty=0&depth=1&type=post'); ?>
				<?php foreach($categories as $category) { ?>
				<option value='<?php echo esc_attr($category->term_id); ?>' <?php if ($category->term_id == $instance['categories']) echo 'selected="selected"'; ?>><?php echo esc_attr($category->cat_name); ?></option>
				<?php } ?>
			</select>
		</p>
        
        <p>
			<label for="<?php echo esc_attr($this->get_field_id('layout')); ?>"><?php esc_html_e('Layout','sermonaddons'); ?>: </label>
			<select id="<?php echo esc_attr($this->get_field_id('layout')); ?>" name="<?php echo esc_attr($this->get_field_name('layout')); ?>" class="widefat">
				<?php 
				$layout_options = apply_filters('em_widget_order_ddm', array(
					'folio_3' => esc_html__('3 Columns','sermonaddons'),
					'folio_2' => esc_html__('2 Columns','sermonaddons'),
					'folio_1' => esc_html__('1 Columns','sermonaddons'),
				)); 
				?>
				<?php foreach( $layout_options as $key => $value) : ?>   
	 			<option value='<?php echo esc_attr($key); ?>' <?php echo esc_attr($key == $instance['layout']) ? "selected='selected'" : ''; ?>>
	 				<?php echo esc_html($value); ?>
	 			</option>
				<?php endforeach; ?>
			</select>
        </p>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('posts')); ?>"><?php esc_html_e('Number of posts','sermonaddons'); ?></label>
			<input class="widefat" style="width: 40px;" id="<?php echo esc_attr($this->get_field_id('posts')); ?>" name="<?php echo esc_attr($this->get_field_name('posts')); ?>" value="<?php echo esc_attr($instance['posts']); ?>" />
		</p>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('offset_posts')); ?>"><?php esc_html_e('Offset posts','sermonaddons'); ?></label>
			<input class="widefat" style="width: 40px;" id="<?php echo esc_attr($this->get_field_id('offset_posts')); ?>" name="<?php echo esc_attr($this->get_field_name('offset_posts')); ?>" value="<?php echo esc_attr($instance['offset_posts']); ?>" />
		</p>
		
        
        		<p>
			<label for="<?php echo esc_attr($this->get_field_id('archive_label')); ?>"><?php esc_html_e('"More Posts" Label (optional)','sermonaddons'); ?></label>
			<input class="widefat" style="width: 100%;" id="<?php echo esc_attr($this->get_field_id('archive_label')); ?>" name="<?php echo esc_attr($this->get_field_name('archive_label')); ?>" value="<?php echo esc_attr($instance['archive_label']); ?>" />
		</p>
        
        <p>
			<label for="<?php echo esc_attr($this->get_field_id('archive_link')); ?>"><?php esc_html_e('"More Posts" URL (optional)','sermonaddons'); ?></label>
			<input class="widefat" style="width: 100%;" id="<?php echo esc_attr($this->get_field_id('archive_link')); ?>" name="<?php echo esc_attr($this->get_field_name('archive_link')); ?>" value="<?php echo esc_attr($instance['archive_link']); ?>" />
		</p>
	<?php }
}
?>