<?php
add_action('widgets_init', 'sermonaddons_sermons_widget');

function sermonaddons_sermons_widget()
{
	register_widget('sermonaddons_sermons_widget');
}

class sermonaddons_sermons_widget extends WP_Widget {
	
	public function __construct() {
		$widget_ops = array('classname' => 'sermonaddons_sermons_widget', 'description' => esc_html__('!!Posts block for Elementor only!!','sermonaddons'));
       	parent::__construct(false, esc_html__('Themnific: Sermons','sermonaddons'),$widget_ops);  
	}
	
	function widget($args, $instance)
	{
		extract($args);
		
		$post_type = 'all';
		$layout = esc_attr($instance['layout']);
		$categories = isset( $instance['categories'] ) ? esc_attr( $instance['categories'] ) : '';
		$posts = isset( $instance['posts'] ) ? esc_attr( $instance['posts'] ) : '';
		$offset_posts = isset( $instance['offset_posts'] ) ? esc_attr( $instance['offset_posts'] ) : '';
		
		echo wp_kses_post($before_widget);
		?>
		
		<?php
		$post_types = get_post_types();
		unset($post_types['page'], $post_types['attachment'], $post_types['revision'], $post_types['nav_menu_item']);
		
		if($post_type == 'all') {
			$post_type_array = $post_types;
		} else {
			$post_type_array = $post_type;
		}
		?>
            
			<?php
			
			if($categories === 'all'){
				$recent_posts = new WP_Query(array(
				'showposts' => $posts,
				'offset' => esc_attr($offset_posts),
				'post_type' => 'tmnf_sermon',
			));
			}
			else {
				$recent_posts = new WP_Query(array(
					'showposts' => $posts,
					'offset' => esc_attr($offset_posts),
					'post_type' => 'tmnf_sermon',
					'tax_query' => array(
						array(
							'taxonomy' => 'sermon-category',
							'terms' => $categories,
							'field' => 'term_id',
						)
					),
				));
			}
			
			wp_enqueue_script('masonry');
			wp_enqueue_script('masonry-start', plugin_dir_url(__DIR__).'assets/js/masonry.start.js','','', true);
			
			?>
            <div class="sermon_page sermon_wrap layout_<?php echo esc_attr($layout); ?>">
            
				<?php while($recent_posts->have_posts()): $recent_posts->the_post();
				
				$sermon_speaker = get_post_meta(get_the_ID(), 'sermon_speaker', true);
				
				get_template_part('/post-types/post-sermon');
							
				endwhile;wp_reset_postdata(); ?>
            
			</div>
            
			<div class="clearfix"></div>
		
		<?php
		echo wp_kses_post($after_widget);
	}
	
	function update($new_instance, $old_instance)
	{
		$instance = $old_instance;
		
		$instance['post_type'] = 'all';
		$instance['layout'] = $new_instance['layout'];
		$instance['categories'] = $new_instance['categories'];
		$instance['posts'] = sanitize_text_field($new_instance['posts']);
		$instance['offset_posts'] = sanitize_text_field($new_instance['offset_posts']);
		
		return $instance;
	}

	function form($instance)
	{
		$defaults = array( 'post_type' => 'all','layout' => 'folio_3', 'categories' => 'all', 'posts' => 4, 'offset_posts' => '');
		$instance = wp_parse_args((array) $instance, $defaults); ?>

		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('categories')); ?>"><?php esc_html_e('Filter by Category','sermonaddons'); ?></label> 
			<select id="<?php echo esc_attr($this->get_field_id('categories')); ?>" name="<?php echo esc_attr($this->get_field_name('categories')); ?>" class="widefat categories">
				<option value='all' <?php if ('all' == $instance['categories']) echo 'selected="selected"'; ?>></option>
				<?php $categories = get_categories($args = array(
															'type'		=> 'tmnf_sermon',
															'orderby'	=> 'name',
															'order'		=> 'ASC',
															'taxonomy'	=> 'sermon-category'
															)) ?>
				<?php foreach($categories as $category) { ?>
				<option value='<?php echo esc_attr($category->term_id); ?>' <?php if ($category->term_id == $instance['categories']) echo 'selected="selected"'; ?>><?php echo esc_attr($category->cat_name); ?></option>
				<?php } ?>
			</select>
		</p>
        
        <p>
			<label for="<?php echo esc_attr($this->get_field_id('layout')); ?>"><?php esc_html_e('Layout','sermonaddons'); ?>: </label>
			<select id="<?php echo esc_attr($this->get_field_id('layout')); ?>" name="<?php echo esc_attr($this->get_field_name('layout')); ?>" class="widefat">
				<?php 
				$layout_options = apply_filters('em_widget_order_ddm', array(
					'folio_3' => esc_html__('3 Columns','sermonaddons'),
					'folio_2' => esc_html__('2 Columns','sermonaddons'),
					'folio_1' => esc_html__('1 Columns','sermonaddons')
				)); 
				?>
				<?php foreach( $layout_options as $key => $value) : ?>   
	 			<option value='<?php echo esc_attr($key); ?>' <?php echo esc_attr($key == $instance['layout']) ? "selected='selected'" : ''; ?>>
	 				<?php echo esc_html($value); ?>
	 			</option>
				<?php endforeach; ?>
			</select>
        </p>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('posts')); ?>"><?php esc_html_e('Number of posts','sermonaddons'); ?></label>
			<input class="widefat" style="width: 40px;" id="<?php echo esc_attr($this->get_field_id('posts')); ?>" name="<?php echo esc_attr($this->get_field_name('posts')); ?>" value="<?php echo esc_attr($instance['posts']); ?>" />
		</p>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('offset_posts')); ?>"><?php esc_html_e('Offset posts','sermonaddons'); ?></label>
			<input class="widefat" style="width: 40px;" id="<?php echo esc_attr($this->get_field_id('offset_posts')); ?>" name="<?php echo esc_attr($this->get_field_name('offset_posts')); ?>" value="<?php echo esc_attr($instance['offset_posts']); ?>" />
		</p>
		

	<?php }
}
?>